@@ -1,7 +1,8 @@
+
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2021 The Cacti Group                                 |
+ | Copyright (C) 2004-2022 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -395,7 +396,7 @@ function form_actions() {
 				print "<tr>
 					<td class='textArea'>
 						<p>" . __('The selected Aggregate Graphs does not appear to have any matching Aggregate Templates.') . "</p>
-						<p>" . __('In order to migrate the Aggregate Graphs below use an Aggregate Template, one must already exist.  Please press \'Return\' and then first create your Aggergate Template before retrying.') . "</p>
+						<p>" . __('In order to migrate the Aggregate Graphs below use an Aggregate Template, one must already exist.  Please press \'Return\' and then first create your Aggregate Template before retrying.') . "</p>
 						<div class='itemlist'><ul>$graph_list</ul></div>
 					</td>
 				</tr>";
@@ -486,7 +487,7 @@ function form_actions() {
 				print "<tr><td class='even'><span class='textError'>" . __('You currently have no reports defined.') . "</span></td></tr>";
 				$save_html = "<input type='button' class='ui-button ui-corner-all ui-widget' value='" . __esc('Return') . "' onClick='cactiReturnTo()'>";
 			}
-		} elseif (get_request_var('drp_action') == '5') { // conver to a normal graph
+		} elseif (get_request_var('drp_action') == '5') { // convert to a normal graph
 			print "<tr>
 				<td colspan='2' class='textArea'>
 					<p>" . __('Click \'Continue\' to convert the following Aggregate Graph(s) into a normal Graph.') . "</p>
@@ -555,6 +556,9 @@ function form_actions() {
 function item() {
 	global $consolidation_functions, $graph_item_types, $struct_graph_item;
 
+	// Remove filter item
+	unset($struct_graph_item['data_template_id']);
+
 	/* ================= input validation ================= */
 	get_filter_request_var('id');
 	/* ==================================================== */
@@ -567,13 +571,23 @@ function item() {
 		$template_item_list = db_fetch_assoc_prepared('SELECT
 			gti.id, gti.text_format, gti.value, gti.hard_return, gti.graph_type_id,
 			gti.consolidation_function_id, dtr.data_source_name, gti.alpha,
-			cdef.name AS cdef_name, colors.hex
+			cdef.name AS cdef_name, vdef.name AS vdef_name, colors.hex,
+			gtgp.name AS gprint_name
 			FROM graph_templates_item AS gti
-			LEFT JOIN data_template_rrd AS dtr ON (gti.task_item_id=dtr.id)
-			LEFT JOIN data_local AS dl ON (dtr.local_data_id=dl.id)
-			LEFT JOIN data_template_data AS dtd ON (dl.id=dtd.local_data_id)
-			LEFT JOIN cdef ON (gti.cdef_id=cdef.id)
-			LEFT JOIN colors ON (gti.color_id=colors.id)
+			LEFT JOIN data_template_rrd AS dtr
+			ON gti.task_item_id=dtr.id
+			LEFT JOIN data_local AS dl
+			ON dtr.local_data_id=dl.id
+			LEFT JOIN data_template_data AS dtd
+			ON dl.id=dtd.local_data_id
+			LEFT JOIN cdef
+			ON gti.cdef_id=cdef.id
+			LEFT JOIN vdef
+			ON gti.vdef_id=vdef.id
+			LEFT JOIN graph_templates_gprint gtgp
+			ON gti.gprint_id=gtgp.id
+			LEFT JOIN colors
+			ON gti.color_id=colors.id
 			WHERE gti.local_graph_id = ?
 			ORDER BY gti.sequence',
 			array(get_request_var('id')));
@@ -603,6 +617,9 @@ function item() {
 function graph_edit() {
 	global $config, $struct_graph, $struct_aggregate_graph, $image_types, $consolidation_functions, $graph_item_types, $struct_graph_item;
 
+	// Remove filter item
+	unset($struct_graph_item['data_template_id']);
+
 	/* ================= input validation ================= */
 	get_filter_request_var('id');
 	/* ==================================================== */
@@ -754,7 +771,7 @@ function graph_edit() {
 
 		if (!cacti_sizeof($graph)) {
 			html_start_box(__('Aggregate Preview Does Not Exist'), '100%', '', '3', 'center', '');
-			print "<tr><td id='imagewindow' class='center'>" . __('Aggreage Graph does not Exist') . '</tr></tr>';
+			print "<tr><td id='imagewindow' class='center'>" . __('Aggregate Graph does not Exist') . '</tr></tr>';
 			html_end_box(false);
 			raise_message('noaggregate', __('Aggregate Graph does not Exist'), MESSAGE_LEVEL_ERROR);
 			return false;
@@ -805,7 +822,7 @@ function graph_edit() {
 
 	form_start('aggregate_graphs.php', 'template_edit');
 
-	/* we will show the templated representation only when when there is a template and propagation is enabled */
+	/* we will show the templated representation only when there is a template and propagation is enabled */
 	if (!isempty_request_var('id') && $current_tab == 'details') {
 		if (cacti_sizeof($template)) {
 			print "<div id='templated'>";
