@@ -40,18 +40,18 @@ $version  = get_cacti_version(); // Get the current Cacti version
 /* initialize some variables */
 $user          = array();                             // An array that will include all user details
 $user_enabled  = true;                                // A variable to let plugins know that the user is enabled
-$guest_user    = false;                               // Indicates the the Guest account is being used
+$guest_user    = false;                               // Indicates the Guest account is being used
 $realm         = 0;                                   // The compensated realm used for template and user validation
 $frv_realm     = get_nfilter_request_var('realm', 0); // The dropdown value for realm
 $auth_method   = read_config_option('auth_method');   // The authentication method for Cacti
 $error         = false;                               // Global variable, will be true if any errors occur
 $error_msg     = '';                                  // The errors message in case there was a login error
 
-/* glboal variables for exception handling */
+/* global variables for exception handling */
 global $error, $error_msg;
 
 if (get_nfilter_request_var('action') == 'login' || $auth_method == 2) {
-	if ($auth_method >= 2 && $frv_realm <= 1) {
+	if ($auth_method > 2 && $frv_realm <= 1) {
 		// User picked 'local' from dropdown;
 		$auth_method = 1;
 	} else {
@@ -142,7 +142,7 @@ if (get_nfilter_request_var('action') == 'login' || $auth_method == 2) {
 		} else {
 			/* error */
 			$error     = true;
-			$error_msg = __('Access Denied!  Guest user id %s does not exist.  Please contact your Adminitrator.', read_config_option('guest_user'));
+			$error_msg = __('Access Denied!  Guest user id %s does not exist.  Please contact your Administrator.', read_config_option('guest_user'));
 
 			cacti_log("LOGIN FAILED: Unable to locate guest user '" . read_config_option('guest_user') . "'", false, 'AUTH');
 
@@ -199,7 +199,7 @@ if (get_nfilter_request_var('action') == 'login' || $auth_method == 2) {
 		}
 
 		/* remember me support.  Not for guest of basic auth */
-		if ($auth_method != 2 && $username != get_guest_account()) {
+		if ($auth_method != 2 && $user['id'] !== get_guest_account()) {
 			if (!$error && isset_request_var('remember_me') && read_config_option('auth_cache_enabled') == 'on') {
 				set_auth_cookie($user);
 			}
@@ -367,7 +367,7 @@ $selectedTheme = get_selected_theme();
 						</tr>
 					<?php } ?>
 						<tr>
-							<td cospan='2'>
+							<td colspan='2'>
 								<input type='submit' class='ui-button ui-corner-all ui-widget' value='<?php print __esc('Login');?>'>
 							</td>
 						</tr>
