@@ -1,8 +1,8 @@
-#!/usr/bin/php -q
+#!/usr/bin/env php
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2020 The Cacti Group                                 |
+ | Copyright (C) 2004-2022 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -37,6 +37,11 @@ require_once($config['base_path'] . '/lib/sort.php');
 require_once($config['base_path'] . '/lib/template.php');
 require_once($config['base_path'] . '/lib/utility.php');
 
+/* switch to main database for cli's */
+if ($config['poller_id'] > 1) {
+	db_switch_remote_to_main();
+}
+
 /* process calling arguments */
 $parms = $_SERVER['argv'];
 array_shift($parms);
@@ -365,7 +370,7 @@ if (cacti_sizeof($parms)) {
 		}
 	}
 
-	/* Verify the host's existance */
+	/* Verify the host's existence */
 	if (!isset($hosts[$host_id]) || $host_id == 0) {
 		print "ERROR: Unknown Host ID ($host_id)\n";
 		print "Try --list-hosts\n";
@@ -519,7 +524,7 @@ if (cacti_sizeof($parms)) {
 					$field_name       = $option_value[0];
 				}
 
-				/* check for the input fields existance */
+				/* check for the input fields existence */
 				$field_found = false;
 				if (cacti_sizeof($input_fields)) {
 					foreach ($input_fields as $key => $row) {
@@ -773,7 +778,7 @@ function display_help() {
 	print "    [--graph-title=S]       Defaults to what ever is in the Graph Template/Data Template.\n";
 	print "    [--reindex-method=N]    The reindex method to be used for that data query.\n";
 	print "                            NOTE: If Data Query is already associated, the reindex method will NOT be changed.\n\n";
-	print "    Valid --reindex-methos include\n";
+	print "    Valid --reindex-methods include\n";
 	print "        0|None   = No reindexing\n";
 	print "        1|Uptime = Uptime goes Backwards (Default)\n";
 	print "        2|Index  = Index Count Changed\n";
