@@ -1,8 +1,8 @@
-#!/usr/bin/php -q
+#!/usr/bin/env php
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2019 The Cacti Group                                 |
+ | Copyright (C) 2004-2022 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -30,6 +30,11 @@ require_once($config['base_path'] . '/lib/utility.php');
 
 ini_set('max_execution_time', '0');
 
+/* switch to main database for cli's */
+if ($config['poller_id'] > 1) {
+	db_switch_remote_to_main();
+}
+
 /* process calling arguments */
 $parms = $_SERVER['argv'];
 array_shift($parms);
@@ -171,7 +176,7 @@ function display_help() {
 	print "\nusage: poller_data_sources_reapply_names.php --host-id=[id|all][N1,N2,...] [--filter=string] [--debug]\n\n";
 	print "A utility that will recalculate Data Source names for the selected Data Templates.\n\n";
 	print "Required:\n";
-	print "    --host-id=N|all|N1,N2,... - The deivces id, 'all' or a comma delimited list of id's\n\n";
+	print "    --host-id=N|all|N1,N2,... - The devices id, 'all' or a comma delimited list of id's\n\n";
 	print "Optional:\n";
 	print "    --filter=search           - A Data Template name or Data Source Title to search for\n";
 	print "    --debug                   - Display verbose output during execution\n\n";
