@@ -166,7 +166,7 @@ $exists = db_fetch_cell_prepared('SELECT COUNT(*)
 	WHERE poller_id = ?',
 	array($poller_id));
 
-if (empty($exists)) {
+if ($exists == 0 && $poller_id > 1) {
 	record_cmdphp_done();
 	db_close();
 	exit(-1);
@@ -194,7 +194,7 @@ if ($allhost) {
 	$params3    = array($poller_interval, $poller_interval, $poller_interval, $poller_id);
 } else {
 	$sql_where0 = 'WHERE poller_id > ?';
-	$sql_where1 = ' AND h.id >= ? AND h.id <= ?';
+	$sql_where1 = ' AND ((h.id >= ? AND h.id <= ?) OR h.id IS NULL)';
 	$sql_where2 = ' AND pi.host_id >= ? AND pi.host_id <= ?';
 	$sql_where3 = ' AND pi.host_id >= ? AND pi.host_id <= ?';
 
@@ -317,6 +317,23 @@ if (cacti_sizeof($poller_items) && read_config_option('poller_enabled') == 'on')
 			if ($last_host != '') {
 				$host_end = microtime(true);
 
+				if ($output_count > 0) {
+					cacti_log("Device[$last_host] Writing $output_count items to Poller Output Table", $print_data_to_stdout, 'POLLER', debug_level($host_id, POLLER_VERBOSITY_MEDIUM));
+
+					db_execute('INSERT IGNORE INTO poller_output
+						(local_data_id, rrd_name, time, output)
+						VALUES ' . implode(', ', $output_array), true, $poller_db_cnn_id);
+
+					if (read_config_option('boost_redirect') == 'on' && read_config_option('boost_rrd_update_enable') == 'on') {
+						db_execute('INSERT IGNORE INTO poller_output_boost
+							(local_data_id, rrd_name, time, output)
+							VALUES ' . implode(', ', $output_array), true, $poller_db_cnn_id);
+					}
+
+					$output_array = array();
+					$output_count = 0;
+				}
+
 				db_execute_prepared('UPDATE host
 					SET polling_time = ?
 					WHERE id = ?
@@ -334,7 +351,6 @@ if (cacti_sizeof($poller_items) && read_config_option('poller_enabled') == 'on')
 
 					$tot_errors += $errors;
 				}
-
 			}
 
 			$error_ds    = array();
@@ -369,7 +385,9 @@ if (cacti_sizeof($poller_items) && read_config_option('poller_enabled') == 'on')
 				$output_array[] = sprintf('(%d, %s, CURRENT_TIMESTAMP(), %s)', $item['local_data_id'], db_qstr($item['rrd_name']), db_qstr($output));
 			}
 
-			if ($output_count > 1000) {
+			if ($output_count > 2000) {
+				cacti_log("Device[$host_id] Writing $output_count items to Poller Output Table", $print_data_to_stdout, 'POLLER', debug_level($host_id, POLLER_VERBOSITY_MEDIUM));
+
 				db_execute('INSERT IGNORE INTO poller_output
 					(local_data_id, rrd_name, time, output)
 					VALUES ' . implode(', ', $output_array), true, $poller_db_cnn_id);
@@ -398,6 +416,21 @@ if (cacti_sizeof($poller_items) && read_config_option('poller_enabled') == 'on')
 	// Record the last hosts polling time
 	$host_end = microtime(true);
 
+	// Flush the items to the output table
+	if ($output_count > 0) {
+		cacti_log("Device[$host_id] Writing $output_count items to Poller Output Table", $print_data_to_stdout, 'POLLER', debug_level($host_id, POLLER_VERBOSITY_MEDIUM));
+
+		db_execute('INSERT IGNORE INTO poller_output
+			(local_data_id, rrd_name, time, output)
+			VALUES ' . implode(', ', $output_array), true, $poller_db_cnn_id);
+
+		if (read_config_option('boost_redirect') == 'on' && read_config_option('boost_rrd_update_enable') == 'on') {
+			db_execute('INSERT IGNORE INTO poller_output_boost
+				(local_data_id, rrd_name, time, output)
+				VALUES ' . implode(', ', $output_array), true, $poller_db_cnn_id);
+		}
+	}
+
 	db_execute_prepared('UPDATE host
 		SET polling_time = ?
 		WHERE id = ?
@@ -420,18 +453,6 @@ if (cacti_sizeof($poller_items) && read_config_option('poller_enabled') == 'on')
 		cacti_log('WARNING: Long Responses Errors[' . cacti_sizeof($width_dses) . '] DS[' . implode(', ', $width_dses) . ']', false, 'POLLER');
 	}
 
-	if ($output_count > 0) {
-		db_execute('INSERT IGNORE INTO poller_output
-			(local_data_id, rrd_name, time, output)
-			VALUES ' . implode(', ', $output_array), true, $poller_db_cnn_id);
-
-		if (read_config_option('boost_redirect') == 'on' && read_config_option('boost_rrd_update_enable') == 'on') {
-			db_execute('INSERT IGNORE INTO poller_output_boost
-				(local_data_id, rrd_name, time, output)
-				VALUES ' . implode(', ', $output_array), true, $poller_db_cnn_id);
-		}
-	}
-
 	if ($using_proc_function && $script_server_calls > 0) {
 		// close php server process
 		@fwrite($pipes[0], "quit\r\n");
