@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2020 The Cacti Group                                 |
+ | Copyright (C) 2004-2022 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -148,7 +148,7 @@ function aggregate_color_form_save() {
 			$save1['color_template_id'] = 0;
 		}
 
-		$save1['name'] = form_input_validate(get_nfilter_request_var('name'), 'name', '', false, 3);
+		$save1['name'] = form_input_validate(get_filter_request_var('name', FILTER_SANITIZE_SPECIAL_CHARS), 'name', '', false, 3);
 
 		cacti_log('Saved ID: ' . $save1['color_template_id'] . ' Name: ' . $save1['name'], false, 'AGGREGATE', POLLER_VERBOSITY_DEBUG);
 
@@ -256,7 +256,7 @@ function aggregate_color_form_actions() {
 		} elseif (get_request_var('drp_action') == '3') { // sync
 			print "<tr>
 				<td class='textArea'>
-					<p>" . __n('Click \'Continue\' to Synchronize all Aggregate Graphs with the selected Color Template.', 'Click \'Continue\' to Syncrhonize all Aggregate Graphs with the selected Color Templates.', cacti_sizeof($color_array)) . "</p>
+					<p>" . __n('Click \'Continue\' to Synchronize all Aggregate Graphs with the selected Color Template.', 'Click \'Continue\' to Synchronize all Aggregate Graphs with the selected Color Templates.', cacti_sizeof($color_array)) . "</p>
 					<div class='itemlist'><ul>$color_list</ul></div></p>
 				</td>
 			</tr>";
@@ -324,41 +324,47 @@ function aggregate_color_item() {
 	html_end_box();
 
     ?>
-    <script type='text/javascript'>
+	<script type='text/javascript'>
 
-    $(function() {
-        $('#color_templates_template_edit2_child').attr('id', 'color_item');
-        $('.cdialog').remove();
-        $('body').append("<div class='cdialog' id='cdialog'></div>");
+	$(function() {
+		$('#color_templates_template_edit2_child').attr('id', 'color_item');
+		$('.cdialog').remove();
+		$('#main').append("<div class='cdialog' id='cdialog'></div>");
 
 		<?php if (read_config_option('drag_and_drop') == 'on') { ?>
-        $('#color_item').tableDnD({
-            onDrop: function(table, row) {
-                loadPageNoHeader('color_templates_items.php?action=ajax_dnd&id=<?php isset_request_var('color_template_id') ? print get_request_var('color_template_id') : print 0;?>&'+$.tableDnD.serialize());
-            }
-        });
+		$('#color_item').tableDnD({
+			onDrop: function(table, row) {
+				loadPageNoHeader('color_templates_items.php?action=ajax_dnd&id=<?php isset_request_var('color_template_id') ? print get_request_var('color_template_id') : print 0;?>&'+$.tableDnD.serialize());
+			}
+		});
 		<?php } ?>
 
-        $('.delete').click(function (event) {
-            event.preventDefault();
+		$('.delete').click(function (event) {
+			event.preventDefault();
 
-            id = $(this).attr('id').split('_');
-            request = 'color_templates_items.php?action=item_remove_confirm&id='+id[0]+'&color_id='+id[1];
-            $.get(request)
-		.done(function(data) {
-	                $('#cdialog').html(data);
-        	        applySkin();
-			$('#cdialog').dialog({ title: '<?php print __('Delete Color Item');?>', minHeight: 80, minWidth: 500 });
- 		})
-		.fail(function(data) {
-			getPresentHTTPError(data);
-		});
-        }).css('cursor', 'pointer');
-    });
+			id = $(this).attr('id').split('_');
+			request = 'color_templates_items.php?action=item_remove_confirm&id='+id[0]+'&color_id='+id[1];
+			$.get(request)
+				.done(function(data) {
+					$('#cdialog').html(data);
 
-    </script>
-    <?php
+					applySkin();
 
+					$('#cdialog').dialog({
+						title: '<?php print __('Delete Color Item');?>',
+						close: function () { $('.delete').blur(); $('.selectable').removeClass('selected'); },
+						minHeight: 80,
+						minWidth: 500
+					});
+				})
+				.fail(function(data) {
+					getPresentHTTPError(data);
+				});
+		}).css('cursor', 'pointer');
+	});
+
+	</script>
+	<?php
 }
 
 /* ----------------------------
