@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2020 The Cacti Group                                 |
+ | Copyright (C) 2004-2022 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -387,7 +387,7 @@ function debug_wizard() {
 			'display' => __('RRD Updated'),
 			'align'   => 'center',
 			'sort'    => '',
-			'tip'     => __('Determines if the RRDfile has been writted to properly.'),
+			'tip'     => __('Determines if the RRDfile has been written to properly.'),
 		),
 		'nosort8' => array(
 			'display' => __('Issues'),
@@ -520,12 +520,21 @@ function debug_wizard() {
 
 	if (cacti_sizeof($checks)) {
 		foreach ($checks as $check) {
-			$info = unserialize($check['info']);
-			$issues = explode("\n", $check['issue']);
-			$issue_line = '';
+			if (isset($check['info']) && $check['info'] != '') {
+				$info = unserialize($check['info']);
+			} else {
+				$info = '';
+			}
 
+			if (isset($check['issue']) && $check['issue'] != '') {
+				$issues = explode("\n", $check['issue']);
+			} else {
+				$issues = array();
+			}
+
+			$iline  = '';
 			if (cacti_sizeof($issues)) {
-				$issue_line = $issues[0];
+				$iline = $issues[0];
 			}
 
 			$issue_title = implode('<br/>',$issues);
@@ -538,7 +547,7 @@ function debug_wizard() {
 				form_selectable_ecell($check['username'], $check['local_data_id']);
 				form_selectable_cell(date($datefmt, $check['started']), $check['local_data_id'], '', 'right');
 				form_selectable_cell($check['local_data_id'], $check['local_data_id'], '', 'right');
-				form_selectable_cell(debug_icon(($check['done'] ? (strlen($issue_line) ? 'off' : 'on'):'')), $check['local_data_id'], '', 'center');
+				form_selectable_cell(debug_icon(($check['done'] ? ($iline != '' ? 'off' : 'on'):'')), $check['local_data_id'], '', 'center');
 				form_selectable_cell(debug_icon($info['rrd_writable']), $check['local_data_id'], '', 'center');
 				form_selectable_cell(debug_icon($info['rrd_exists']), $check['local_data_id'], '', 'center');
 				form_selectable_cell(debug_icon($info['active']), $check['local_data_id'], '', 'center');
@@ -551,7 +560,7 @@ function debug_wizard() {
 					form_selectable_cell(debug_icon(($info['rra_timestamp2'] != '' ? 1 : '')), $check['local_data_id'], '', 'center');
 				}
 
-				form_selectable_cell('<a class=\'linkEditMain\' href=\'#\' title="' . html_escape($issue_title) . '">' . ($issue_line != '' ? __esc('Issues') : __esc('N/A')) . '</a>', $check['local_data_id'], '', 'right');
+				form_selectable_cell('<a class=\'linkEditMain\' href=\'#\' title="' . html_escape($issue_title) . '">' . ($iline != '' ? __esc('Issues') : __esc('N/A')) . '</a>', $check['local_data_id'], '', 'right');
 			} else {
 				form_selectable_cell('-', $check['local_data_id']);
 				form_selectable_cell(__('Not Debugging'), $check['local_data_id'], '', 'right');
@@ -817,7 +826,7 @@ function debug_view() {
 
 				$output = '';
 				foreach($details as $attribute => $recommendation) {
-					$output .= __('For attrbitute \'%s\', issue found \'%s\'', $attribute, $recommendation);
+					$output .= __('For attribute \'%s\', issue found \'%s\'', $attribute, $recommendation);
 				}
 
 				form_selectable_cell($output, 'line_2' . $i);
@@ -969,7 +978,7 @@ function data_debug_filter() {
 
 							if (cacti_sizeof($templates) > 0) {
 								foreach ($templates as $template) {
-									print "<option value='" . $template['id'] . "'"; if (get_request_var('template_id') == $template['id']) { print ' selected'; } print '>' . title_trim(html_escape($template['name']), 40) . "</option>";
+									print "<option value='" . $template['id'] . "'"; if (get_request_var('template_id') == $template['id']) { print ' selected'; } print '>' . html_escape($template['name']) . '</option>';
 								}
 							}
 							?>
@@ -997,7 +1006,7 @@ function data_debug_filter() {
 							$profiles = array_rekey(db_fetch_assoc('SELECT id, name FROM data_source_profiles ORDER BY name'), 'id', 'name');
 							if (cacti_sizeof($profiles)) {
 								foreach ($profiles as $key => $value) {
-									print "<option value='" . $key . "'"; if (get_request_var('profile') == $key) { print ' selected'; } print '>' . html_escape($value) . "</option>";
+									print "<option value='" . $key . "'"; if (get_request_var('profile') == $key) { print ' selected'; } print '>' . html_escape($value) . '</option>';
 								}
 							}
 							?>
@@ -1063,7 +1072,7 @@ function data_debug_filter() {
 							<?php
 							if (cacti_sizeof($item_rows) > 0) {
 								foreach ($item_rows as $key => $value) {
-									print "<option value='" . $key . "'"; if (get_request_var('rows') == $key) { print ' selected'; } print '>' . html_escape($value) . "</option>";
+									print "<option value='" . $key . "'"; if (get_request_var('rows') == $key) { print ' selected'; } print '>' . html_escape($value) . '</option>';
 								}
 							}
 							?>
