@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2021 The Cacti Group                                 |
+ | Copyright (C) 2004-2022 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -239,7 +239,7 @@ function form_save() {
 
 		if (!is_error_message()) {
 			/* if this is a new data source and a template has been selected, skip item creation this time
-			otherwise it throws off the templatate creation because of the NULL data */
+			otherwise it throws off the template creation because of the NULL data */
 			if (!isempty_request_var('local_data_id') || isempty_request_var('data_template_id')) {
 				/* if no template was set before the save, there will be only one data source item to save;
 				otherwise there might be >1 */
@@ -895,9 +895,11 @@ function ds_edit() {
 			foreach($dts as $dtid) {
 				$dtids[] = $dtid['data_template_id'];
 			}
-		}
 
-		$dtsql = 'SELECT id, name FROM data_template WHERE id IN(' . implode(',', $dtids) . ') ORDER BY name';
+			$dtsql = 'SELECT id, name FROM data_template WHERE id IN(' . implode(',', $dtids) . ') ORDER BY name';
+		} else {
+			$dtsql = 'SELECT id, name FROM data_template ORDER BY name';
+		}
 	} else {
 		$dtsql = 'SELECT id, name FROM data_template ORDER BY name';
 	}
@@ -1437,7 +1439,7 @@ function ds() {
 						<?php print __('Search');?>
 					</td>
 					<td>
-						<input type='text' class='ui-state-default ui-corner-all' id='rfilter' size='30' value='<?php print html_escape_request_var('rfilter');?>' onChange='applyFilter()'>
+						<input type='text' class='ui-state-default ui-corner-all' id='rfilter' size='55' value='<?php print html_escape_request_var('rfilter');?>' onChange='applyFilter()'>
 					</td>
 					<td>
 						<?php print __('Data Sources');?>
@@ -1511,9 +1513,9 @@ function ds() {
 	if (get_request_var('status') == '-1') {
 		/* Show all items */
 	} elseif (get_request_var('status') == '1') {
-		$sql_where1 .= ($sql_where1 != '' ? ' AND':'WHERE') . ' dtd.active="on"';
+		$sql_where1 .= ($sql_where1 != '' ? ' AND':'WHERE') . ' (dtd.active = "on" AND h.disabled = "")';
 	} elseif (get_request_var('status') == '2') {
-		$sql_where1 .= ($sql_where1 != '' ? ' AND':'WHERE') . ' dtd.active=""';
+		$sql_where1 .= ($sql_where1 != '' ? ' AND':'WHERE') . ' (dtd.active = "" OR h.disabled != "")';
 	} elseif (get_request_var('status') == '3') {
 		$sql_where1 .= ($sql_where1 != '' ? ' AND':'WHERE') . ' (dl.snmp_index = "" AND dl.snmp_query_id > 0)';
 	}
@@ -1577,7 +1579,7 @@ function ds() {
 			INNER JOIN data_template_data AS dtd
 			ON dl.id=dtd.local_data_id
 			LEFT JOIN data_template AS dt
-			ON dt.id=dl.data_template_id
+			ON dt.id = dl.data_template_id
 			LEFT JOIN host AS h
 			ON h.id = dl.host_id
 			$sql_where1");
@@ -1588,7 +1590,7 @@ function ds() {
 			INNER JOIN data_template_data AS dtd
 			ON dl.id=dtd.local_data_id
 			LEFT JOIN data_template AS dt
-			ON dt.id=dl.data_template_id
+			ON dt.id = dl.data_template_id
 			LEFT JOIN host AS h
 			ON h.id = dl.host_id
 			$sql_where1
@@ -1609,7 +1611,7 @@ function ds() {
 			'display' => __('Data Source Name'),
 			'align'   => 'left',
 			'sort'    => 'ASC',
-			'tip'     => __('The name of this Data Source. Generally programtically generated from the Data Template definition.')
+			'tip'     => __('The name of this Data Source. Generally programmatically generated from the Data Template definition.')
 		),
 		'local_data_id' => array(
 			'display' => __('ID'),
@@ -1685,8 +1687,14 @@ function ds() {
 
 			$graphs_aggregates_url = get_graphs_aggregates_url($data_source['local_data_id']);
 
+			if ($data_source['name_cache'] == '') {
+				$name = __('Damaged Data Source Name');
+			} else {
+				$name = $data_source['name_cache'];
+			}
+
 			form_alternate_row('line' . $data_source['local_data_id'], true, $disabled);
-			form_selectable_cell(filter_value(title_trim($data_source['name_cache'], read_config_option('max_title_length')), get_request_var('rfilter'), 'data_sources.php?action=ds_edit&id=' . $data_source['local_data_id']), $data_source['local_data_id']);
+			form_selectable_cell(filter_value(title_trim($name, read_config_option('max_title_length')), get_request_var('rfilter'), 'data_sources.php?action=ds_edit&id=' . $data_source['local_data_id']), $data_source['local_data_id']);
 			form_selectable_cell($data_source['local_data_id'], $data_source['local_data_id'], '', 'right');
 
 			// Show link to Graphs and Aggregates
@@ -1696,7 +1704,7 @@ function ds() {
 			form_selectable_cell(api_data_source_deletable($data_source['local_data_id']) ? __('Yes') : __('No'), $data_source['local_data_id']);
 			form_selectable_cell(($data_source['active'] == 'on' ? __('Yes'):__('No')), $data_source['local_data_id']);
 			form_selectable_cell($data_template_name, $data_source['local_data_id']);
-			form_checkbox_cell($data_source['name_cache'], $data_source['local_data_id'], $disabled);
+			form_checkbox_cell($name, $data_source['local_data_id'], $disabled);
 			form_end_row();
 		}
 	} else {
