@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2021 The Cacti Group                                 |
+ | Copyright (C) 2004-2022 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -347,7 +347,7 @@ function form_save() {
 			);
 
 			if ($lg_template_id > 0) {
-				change_graph_template($local_graph_id, $gt_id_unparsed);
+				change_graph_template($local_graph_id, $gt_id_unparsed, true);
 
 				$lg_dq_id = db_fetch_cell_prepared('SELECT snmp_query_id
 					FROM graph_local
@@ -672,7 +672,7 @@ function form_actions() {
 				// 		$i++;
 				// 	}
 
-				/* save aggregate graph graph items */
+				/* save aggregate graph - graph items */
 				if (get_request_var('drp_action') == '9') {
 					/* get existing item ids and sequences from graph template */
 					$graph_templates_items = array_rekey(
@@ -2031,7 +2031,7 @@ function graph_management() {
 						<?php print __('Search');?>
 					</td>
 					<td>
-						<input type='text' class='ui-state-default ui-corner-all' id='rfilter' size='30' value='<?php print html_escape_request_var('rfilter');?>'>
+						<input type='text' class='ui-state-default ui-corner-all' id='rfilter' size='55' value='<?php print html_escape_request_var('rfilter');?>'>
 					</td>
 					<td>
 						<?php print __('Graphs');?>
@@ -2071,7 +2071,7 @@ function graph_management() {
 	if (get_request_var('host_id') == '-1') {
 		/* Show all items */
 	} elseif (isempty_request_var('host_id')) {
-		$sql_where2 .= ($sql_where != '' ? ' AND ':'WHERE ') . ' gl.host_id=0';
+		$sql_where  .= ($sql_where != '' ? ' AND ':'WHERE ') . ' gl.host_id=0';
 		$sql_where2 .= ' AND gl.host_id=0';
 	} elseif (!isempty_request_var('host_id')) {
 		$sql_where  .= ($sql_where != '' ? ' AND ':'WHERE ') . ' gl.host_id=' . get_request_var('host_id');
@@ -2194,7 +2194,7 @@ function graph_management() {
 			'display' => __('Graph Name'),
 			'align'   => 'left',
 			'sort'    => 'ASC',
-			'tip'     => __('The Title of this Graph.  Generally programatically generated from the Graph Template definition or Suggested Naming rules.  The max length of the Title is controlled under Settings->Visual.')
+			'tip'     => __('The Title of this Graph.  Generally programmatically generated from the Graph Template definition or Suggested Naming rules.  The max length of the Title is controlled under Settings->Visual.')
 		),
 		'local_graph_id' => array(
 			'display' => __('ID'),
