@@ -57,6 +57,10 @@ function themeReady() {
 				id = $(this).attr('id');
 
 				$(this).selectmenu({
+					open: function(event, ui) {
+						var instance = $(this).selectmenu('instance');
+						instance.menuInstance.focus(null, instance._getSelectedItem());
+					},
 					change: function(event, ui) {
 						$(this).val(ui.item.value).change();
 					},
@@ -196,7 +200,7 @@ function setMenuVisibility() {
 		}
 	});
 
-	// Functon to give life to the Navigation pane
+	// Function to give life to the Navigation pane
 	$('#nav li:has(ul) a.active').unbind().click(function(event) {
 		event.preventDefault();
 
