@@ -60,6 +60,7 @@ function themeReady() {
 
 	/* user menu on the right ... */
 	if ($('.usertabs').length == 0) {
+		$('.loggedInAs').show();
 		$('#userDocumentation').remove();
 		$('#userCommunity').remove();
 		$('.menuHr').remove();
@@ -143,6 +144,10 @@ function themeReady() {
 				id = $(this).attr('id');
 
 				$(this).selectmenu({
+					open: function(event, ui) {
+						var instance = $(this).selectmenu('instance');
+						instance.menuInstance.focus(null, instance._getSelectedItem());
+					},
 					change: function(event, ui) {
 						$(this).val(ui.item.value).change();
 					},
@@ -187,7 +192,7 @@ function themeReady() {
 		hostOpen = false;
 		clearTimeout(hostTimer);
 		clearTimeout(clickTimeout);
-		$('#host').autocomplete('close');
+		$('#host').autocomplete('close').select();
 	}).click(function() {
 		if (hostOpen) {
 			$('#host').autocomplete('close');
@@ -200,6 +205,7 @@ function themeReady() {
 				hostOpen = true;
 			}, 200);
 		}
+		$('#host').select();
 	}).on('mouseenter', function() {
 		$(this).addClass('ui-state-hover');
 		$('input#host').addClass('ui-state-hover');
@@ -267,7 +273,7 @@ function setMenuVisibility() {
 		}
 	});
 
-	// Functon to give life to the Navigation pane
+	// Function to give life to the Navigation pane
 	$('#nav li:has(ul) a.active').unbind().click(function(event) {
 		event.preventDefault();
 
