@@ -13,7 +13,7 @@
  | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           |
  | GNU General Public License for more details.                            |
  +-------------------------------------------------------------------------+
- | Cacti: The Complete RRDtool-based Graphing Solution                     |
+ | Cacti: The Complete RRDTool-based Graphing Solution                     |
  +-------------------------------------------------------------------------+
  | This code is designed, written, and maintained by the Cacti Group. See  |
  | about.php and/or the AUTHORS file for specific developer information.   |
@@ -22,14 +22,7 @@
  +-------------------------------------------------------------------------+
 */
 
-function upgrade_to_1_1_35() {
-	db_install_execute("DELETE FROM data_input_data
-		WHERE data_input_field_id=0");
-
-	db_install_execute("DELETE FROM snmp_query_graph_rrd
-		WHERE data_template_id=0 OR data_template_rrd_id=0");
-
-	db_install_execute("DELETE FROM snmp_query_graph_rrd_sv
-		WHERE data_template_id=0");
+function upgrade_to_1_2_1() {
+	db_install_execute("UPDATE host SET deleted='' WHERE deleted IS NULL");
+	db_install_execute("ALTER TABLE host MODIFY COLUMN deleted char(3) NOT NULL default ''");
 }
-
