@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2019 The Cacti Group                                 |
+ | Copyright (C) 2004-2022 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -23,6 +23,9 @@
 */
 
 function api_delete_graphs(&$local_graph_ids, $delete_type) {
+	/* check for a bad local_graph_id = 0, and remove graphs */
+	api_graph_remove_bad_graphs($local_graph_ids);
+
 	if (!cacti_sizeof($local_graph_ids)) {
 		return;
 	}
@@ -85,6 +88,8 @@ function api_delete_graphs(&$local_graph_ids, $delete_type) {
 			if (cacti_sizeof($data_sources)) {
 				api_data_source_remove_multi($data_sources);
 			}
+		} else {
+			api_graph_remove_multi($local_graph_ids);
 		}
 
 		break;
@@ -97,6 +102,8 @@ function api_delete_graphs(&$local_graph_ids, $delete_type) {
 
 function api_graph_remove($local_graph_id) {
 	if (empty($local_graph_id)) {
+		$local_graph_ids = array($local_graph_id);
+		api_graph_remove_bad_graphs($local_graph_ids);
 		return;
 	}
 
@@ -111,6 +118,26 @@ function api_graph_remove($local_graph_id) {
 	db_execute_prepared('DELETE FROM graph_local WHERE id = ?', array($local_graph_id));
 }
 
+function api_graph_remove_bad_graphs(&$local_graph_ids = array()) {
+	if (cacti_sizeof($local_graph_ids)) {
+		$bad_graph = array_search(0, $local_graph_ids);
+		if ($bad_graph !== false) {
+			unset($local_graph_ids[$bad_graph]);
+
+			db_execute('DELETE FROM graph_local
+				WHERE id = 0');
+
+			db_execute('DELETE FROM graph_templates_graph
+				WHERE local_graph_id = 0
+				AND graph_template_id = 0');
+
+			db_execute('DELETE FROM graph_templates_item
+				WHERE hash = ""
+				AND local_graph_id = 0');
+		}
+	}
+}
+
 function api_graph_remove_aggregate_items($local_graph_ids) {
 	if (!is_array($local_graph_ids)) {
 		$local_graph_ids = explode(',', $local_graph_ids);
@@ -134,6 +161,9 @@ function api_graph_remove_aggregate_items($local_graph_ids) {
 }
 
 function api_graph_remove_multi($local_graph_ids) {
+	/* check for a bad local_graph_id = 0, and remove graphs */
+	api_graph_remove_bad_graphs($local_graph_ids);
+
 	if (!cacti_sizeof($local_graph_ids)) {
 		return;
 	}
@@ -264,7 +294,7 @@ function api_reapply_suggested_graph_title($local_graph_id) {
 			}
 		}
 
-		if (sizeof($matches)) {
+		if (cacti_sizeof($matches)) {
 			return true;
 		}
 	}
