@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2021 The Cacti Group                                 |
+ | Copyright (C) 2004-2022 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -52,7 +52,7 @@ function nth_percentile($local_data_ids, $start_seconds, $end_seconds, $percenti
 }
 
 /* rrdtool_function_stats - given a data source, calculate a number of statistics for an RRDfile or files
-   over a specified time time period
+   over a specified time period
    @arg $local_data_ids - the data source array to perform the Nth percentile calculation
    @arg $start_seconds - start seconds of time range
    @arg $stop_seconds - stop seconds of time range
@@ -97,7 +97,7 @@ function rrdtool_function_stats($local_data_ids, $start_seconds, $end_seconds, $
 		}
 
 		/* clean up unwanted data source items from the AVERAGE cf data */
-		if (cacti_sizeof($fetch_array_avg[$ldi])) {
+		if (isset($fetch_array_avg[$ldi]) && cacti_sizeof($fetch_array_avg[$ldi])) {
 			if (isset($fetch_array_avg[$ldi]['data_source_names'])) {
 				$good_data = true;
 			} else {
@@ -122,7 +122,7 @@ function rrdtool_function_stats($local_data_ids, $start_seconds, $end_seconds, $
 		}
 
 		/* clean up unwanted data source items from the MAX cf data */
-		if (cacti_sizeof($fetch_array_max[$ldi])) {
+		if (isset($fetch_array_max[$ldi]) && cacti_sizeof($fetch_array_max[$ldi])) {
 			if (isset($fetch_array_max[$ldi]['data_source_names'])) {
 				$good_data = true;
 			} else {
@@ -330,13 +330,6 @@ function cacti_stats_calc($array, $ptile = 95) {
    @arg $ds_steps - how many seconds each period represents
    @returns - (array) an array containing each data source item, and its sum */
 function bandwidth_summation($local_data_id, $start_time, $end_time, $rra_steps, $ds_steps) {
-	static $vstats = array();
-
-	// Check the cache for data
-	if (isset($vstats[$local_data_id . '_' . $start_time . '_' . $end_time . '_' . $rra_steps . '_' . $ds_steps])) {
-		return $vstats[$local_data_id . '_' . $start_time . '_' . $end_time . '_' . $rra_steps . '_' . $ds_steps];
-	}
-
 	$fetch_array = @rrdtool_function_fetch($local_data_id, $start_time, $end_time, $rra_steps * $ds_steps);
 
 	if (!isset($fetch_array['data_source_names']) || cacti_count($fetch_array['data_source_names']) == 0) {
@@ -361,9 +354,6 @@ function bandwidth_summation($local_data_id, $start_time, $end_time, $rra_steps,
 		}
 	}
 
-	// Cache the fetch data
-	$vstats[$local_data_id . '_' . $start_time . '_' . $end_time . '_' . $rra_steps . '_' . $ds_steps] = $return_array;
-
 	return $return_array;
 }
 
@@ -398,8 +388,6 @@ function is_graphable_item($item) {
 function variable_nth_percentile(&$regexp_match_array, &$graph, &$graph_item, &$graph_items, $graph_start, $graph_end) {
 	global $graph_item_types;
 
-	static $vstats = array();
-
 	$nth_cache = array();
 
 	if (cacti_sizeof($regexp_match_array) == 0) {
@@ -453,11 +441,6 @@ function variable_nth_percentile(&$regexp_match_array, &$graph, &$graph_item, &$
 		}
 	}
 
-	// Returned the cached value if it exists
-	if (isset($vstats[$graph_item['local_data_id'] . '_' . $percentile . '_' . $type . '_' . $graph_start . '_' . $graph_end])) {
-		$nth_cache = $vstats[$graph_item['local_data_id'] . '_' . $percentile . '_' . $type . '_' . $graph_start . '_' . $graph_end];
-	}
-
 	/* Get the Nth percentile values */
 	if (!cacti_sizeof($nth_cache)) {
 		switch ($type) {
@@ -568,8 +551,6 @@ function variable_nth_percentile(&$regexp_match_array, &$graph, &$graph_item, &$
 			break;
 	}
 
-	$vstats[$graph_item['local_data_id'] . '_' . $percentile . '_' . $type . '_' . $graph_start . '_' . $graph_end] = $nth_cache;
-
 	/* return the final result and round off to two decimal digits */
 	return round($nth, $round_to);
 }
@@ -595,12 +576,10 @@ function variable_nth_percentile(&$regexp_match_array, &$graph, &$graph_item, &$
    @arg $rra_step - how many periods each sample in the RRA counts for, values above '1' result in an
      averaged summation
    @arg $ds_step - how many seconds each period represents
-   @returns - a string containg the bandwidth summation suitable for placing on the graph */
+   @returns - a string containing the bandwidth summation suitable for placing on the graph */
 function variable_bandwidth_summation(&$regexp_match_array, &$graph, &$graph_item, &$graph_items, $graph_start, $graph_end, $rra_step, $ds_step) {
 	global $graph_item_types;
 
-	static $vstats = array();
-
 	if (cacti_sizeof($regexp_match_array) == 0) {
 		return 0;
 	}
