@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2021 The Cacti Group                                 |
+ | Copyright (C) 2004-2022 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -22,13 +22,14 @@
  +-------------------------------------------------------------------------+
 */
 
-function import_xml_data(&$xml_data, $import_as_new, $profile_id, $remove_orphans = false) {
-	global $config, $hash_type_codes, $cacti_version_codes, $preview_only, $import_debug_info, $legacy_template;
+function import_xml_data(&$xml_data, $import_as_new, $profile_id, $remove_orphans = false, $replace_svalues = false, $import_hashes = array()) {
+	global $config, $hash_type_codes, $cacti_version_codes, $ignorable_hashes, $preview_only, $import_debug_info, $legacy_template;
 
 	include_once($config['library_path'] . '/xml.php');
 
-	$info_array    = array();
-	$debug_session = array();
+	$info_array       = array();
+	$debug_session    = array();
+	$ignorable_hashes = array();
 
 	$xml_array = xml2array($xml_data);
 
@@ -46,10 +47,12 @@ function import_xml_data(&$xml_data, $import_as_new, $profile_id, $remove_orphan
 			return $info_array;
 		}
 
-		if (isset($dep_hash_cache[$parsed_hash['type']])) {
-			array_push($dep_hash_cache[$parsed_hash['type']], $parsed_hash);
-		} else {
-			$dep_hash_cache[$parsed_hash['type']] = array($parsed_hash);
+		if (!cacti_sizeof($import_hashes) || in_array($parsed_hash['hash'], $inport_hashes)) {
+			if (isset($dep_hash_cache[$parsed_hash['type']])) {
+				array_push($dep_hash_cache[$parsed_hash['type']], $parsed_hash);
+			} else {
+				$dep_hash_cache[$parsed_hash['type']] = array($parsed_hash);
+			}
 		}
 	}
 
@@ -147,15 +150,55 @@ function import_xml_data(&$xml_data, $import_as_new, $profile_id, $remove_orphan
 
 	$repair = 0;
 
-	/* the order of the $hash_type_codes array is ordered such that the items
-	with the most dependencies are last and the items with no dependencies are first.
-	this means dependencies will just magically work themselves out :) */
+	/**
+	 * We will make two passes through the template array.
+	 *
+	 * In the first pass, we traverse the entire array
+	 * and see what Data Input Methods are present and setup
+	 * and ignore array for problems that have accumulated in
+	 * Templates throughout the years, and in the second pass,
+	 * we will process them.
+	 */
 	foreach ($hash_type_codes as $type => $code) {
 		/* do we have any matches for this type? */
 		if (isset($dep_hash_cache[$type])) {
 			/* yes we do. loop through each match for this type */
 			for ($i=0; $i<cacti_count($dep_hash_cache[$type]); $i++) {
-				$import_debug_info = false;
+				if (!isset($cacti_version_codes[$dep_hash_cache[$type][$i]['version']])) {
+					return false;
+				}
+
+				if (isset($xml_array['hash_' . $hash_type_codes[$dep_hash_cache[$type][$i]['type']] . $cacti_version_codes[$dep_hash_cache[$type][$i]['version']] . $dep_hash_cache[$type][$i]['hash']])) {
+					$hash_array = $xml_array['hash_' . $hash_type_codes[$dep_hash_cache[$type][$i]['type']] . $cacti_version_codes[$dep_hash_cache[$type][$i]['version']] . $dep_hash_cache[$type][$i]['hash']];
+				} elseif (isset($xml_array['hash_' . $hash_type_codes[$dep_hash_cache[$type][$i]['type']] . $dep_hash_cache[$type][$i]['hash']])) {
+					$hash_array = $xml_array['hash_' . $hash_type_codes[$dep_hash_cache[$type][$i]['type']] . $dep_hash_cache[$type][$i]['hash']];
+				} else {
+					raise_message(7); /* xml parse error */
+					return false;
+				}
+
+				if ($type == 'data_input_method') {
+					if (xml_detect_ignorable_hash_cache($dep_hash_cache[$type][$i]['hash'], $hash_array)) {
+						$repair++;
+					}
+				}
+			}
+		}
+	}
+
+	/**
+	 * Second pass, we will actually perform the import of the entirety of the Template.
+	 *
+	 * The order of the $hash_type_codes array is ordered such that the items
+	 * with the most dependencies are last and the items with no dependencies are first.
+	 * this means dependencies will just magically work themselves out :)
+	 */
+	foreach ($hash_type_codes as $type => $code) {
+		/* do we have any matches for this type? */
+		if (isset($dep_hash_cache[$type])) {
+			/* yes we do. loop through each match for this type */
+			for ($i=0; $i<cacti_count($dep_hash_cache[$type]); $i++) {
+				$import_debug_info = array();
 
 				if (!isset($cacti_version_codes[$dep_hash_cache[$type][$i]['version']])) {
 					return false;
@@ -191,7 +234,7 @@ function import_xml_data(&$xml_data, $import_as_new, $profile_id, $remove_orphan
 					$repair++;
 					break;
 				case 'data_query':
-					$hash_cache += xml_to_data_query($dep_hash_cache[$type][$i]['hash'], $hash_array, $hash_cache);
+					$hash_cache += xml_to_data_query($dep_hash_cache[$type][$i]['hash'], $hash_array, $hash_cache, $replace_svalues);
 					break;
 				case 'gprint_preset':
 					$hash_cache += xml_to_gprint_preset($dep_hash_cache[$type][$i]['hash'], $hash_array, $hash_cache);
@@ -223,8 +266,12 @@ function import_xml_data(&$xml_data, $import_as_new, $profile_id, $remove_orphan
 					break;
 				}
 
-				if (!empty($import_debug_info)) {
-					$info_array[$type][isset($info_array[$type]) ? cacti_count($info_array[$type]) : 0] = $import_debug_info;
+				if (cacti_sizeof($import_debug_info)) {
+					if (isset($info_array[$type])) {
+						$info_array[$type][cacti_count($info_array[$type])] = $import_debug_info;
+					} else {
+						$info_array[$type][0] = $import_debug_info;
+					}
 				}
 			}
 		}
@@ -248,7 +295,7 @@ EOD;
     return $public_key;
 }
 
-function import_package($xmlfile, $profile_id = 1, $remove_orphans = false, $preview = false, $info_only = false, $limitex = true) {
+function import_package($xmlfile, $profile_id = 1, $remove_orphans = false, $replace_svalues = false, $preview = false, $info_only = false, $limitex = true, $import_hashes = array(), $import_files = array()) {
 	global $config, $preview_only;
 
 	$preview_only = $preview;
@@ -282,8 +329,10 @@ function import_package($xmlfile, $profile_id = 1, $remove_orphans = false, $pre
 
 				cacti_log('NOTE: Got Package Signature', false, 'IMPORT', POLLER_VERBOSITY_LOW);
 			}
+
 			$xml .= "$x";
 		}
+
 		fclose($f);
 	} else {
 		cacti_log('FATAL: Unable to open file ' . $filename, true, 'IMPORT', POLLER_VERBOSITY_LOW);
@@ -332,7 +381,11 @@ function import_package($xmlfile, $profile_id = 1, $remove_orphans = false, $pre
 		}
 	}
 
-	cacti_log('Writing Files', false, 'IMPORT', POLLER_VERBOSITY_LOW);
+	if (!$preview) {
+		cacti_log('Processing Files for Import', false, 'IMPORT', POLLER_VERBOSITY_LOW);
+	} else {
+		cacti_log('Processing Files for Preview', false, 'IMPORT', POLLER_VERBOSITY_LOW);
+	}
 
 	foreach ($data['files']['file'] as $f) {
 		$fdata = base64_decode($f['data']);
@@ -340,43 +393,52 @@ function import_package($xmlfile, $profile_id = 1, $remove_orphans = false, $pre
 
 		if (strpos($name, 'scripts/') !== false || strpos($name, 'resource/') !== false) {
 			$filename = $config['base_path'] . "/$name";
-			cacti_log('Writing file: ' . $filename, false, 'IMPORT', POLLER_VERBOSITY_LOW);
 
 			if (!$preview) {
-				if ((is_writeable(dirname($filename)) && !file_exists($filename)) || is_writable($filename)) {
-					$file = fopen($filename, 'wb');
+				if (!cacti_sizeof($import_files) || in_array($filename, $import_files)) {
+					cacti_log('Writing file: ' . $filename, false, 'IMPORT', POLLER_VERBOSITY_LOW);
 
-					if (is_resource($file)) {
-						fwrite($file , $fdata, strlen($fdata));
-						fclose($file);
-						clearstatcache();
-						$filestatus[$filename] = __('written');
+					if ((is_writeable(dirname($filename)) && !file_exists($filename)) || is_writable($filename)) {
+						$file = fopen($filename, 'wb');
+
+						if (is_resource($file)) {
+							fwrite($file , $fdata, strlen($fdata));
+							fclose($file);
+							clearstatcache();
+							$filestatus[$filename] = __('written');
+						} else {
+							$filestatus[$filename] = __('could not open');
+						}
+
+						if (!file_exists($filename)) {
+							cacti_log('FATAL: Unable to create directory: ' . $filename, true, 'IMPORT', POLLER_VERBOSITY_LOW);
+
+							$filestatus[$filename] = __('not exists');
+						}
 					} else {
-						$filestatus[$filename] = __('could not open');
+						$filestatus[$filename] = __('not writable');
 					}
 
-					if (!file_exists($filename)) {
-						cacti_log('FATAL: Unable to create directory: ' . $filename, true, 'IMPORT', POLLER_VERBOSITY_LOW);
-
-						$filestatus[$filename] = __('not exists');
-					}
-				} else {
-					$filestatus[$filename] = __('not writable');
+					cacti_log('Write Status file: ' . $filename . ', with Status ' . $filestatus[$filename], false, 'IMPORT', POLLER_VERBOSITY_LOW);
 				}
-
-				cacti_log('Write Status file: ' . $filename . ', with Status ' . $filestatus[$filename], false, 'IMPORT', POLLER_VERBOSITY_LOW);
 			} else {
-				if (!is_writable($filename)) {
-					$filestatus[$filename] = __('not writable');
-				} else {
+				cacti_log('Previewing file: ' . $filename, false, 'IMPORT', POLLER_VERBOSITY_LOW);
+
+				if ((is_writeable(dirname($filename)) && !file_exists($filename)) || is_writable($filename)) {
 					$filestatus[$filename] = __('writable');
+				} else {
+					$filestatus[$filename] = __('not writable');
 				}
 			}
 
 		} else {
-			cacti_log('Importing XML Data for ' . $name, false, 'IMPORT', POLLER_VERBOSITY_LOW);
+			if (!$preview) {
+				cacti_log('Importing XML Data for ' . $name, false, 'IMPORT', POLLER_VERBOSITY_LOW);
+			} else {
+				cacti_log('Previewing XML Data for ' . $name, false, 'IMPORT', POLLER_VERBOSITY_LOW);
+			}
 
-			$debug_data = import_xml_data($fdata, false, $profile_id, $remove_orphans, $preview_only);
+			$debug_data = import_xml_data($fdata, false, $profile_id, $remove_orphans, $replace_svalues, $import_hashes);
 
 			if ($debug_data === false) {
 				return false;
@@ -384,7 +446,9 @@ function import_package($xmlfile, $profile_id = 1, $remove_orphans = false, $pre
 		}
 	}
 
-	cacti_log('File creation complete', false, 'IMPORT', POLLER_VERBOSITY_LOW);
+	if (!$preview) {
+		cacti_log('File creation complete', false, 'IMPORT', POLLER_VERBOSITY_LOW);
+	}
 
 	return array($debug_data, $filestatus);
 }
@@ -408,7 +472,6 @@ function xml_to_graph_template($hash, &$xml_array, &$hash_cache, $hash_version,
 			array($_graph_template_id));
 	} else {
 		$previous_data = array();
-		clear_cached_allowed_types();
 	}
 
 	$save['id']   = (empty($_graph_template_id) ? '0' : $_graph_template_id);
@@ -419,6 +482,12 @@ function xml_to_graph_template($hash, &$xml_array, &$hash_cache, $hash_version,
 		$save['multiple'] = $xml_array['multiple'];
 	}
 
+	if (isset($xml_array['test_source'])) {
+		$save['test_source'] = $xml_array['test_source'];
+	} else {
+		$save['test_source'] = read_config_option('default_test_source');
+	}
+
 	/* check for status changes */
 	$status += compare_data($save, $previous_data, 'graph_templates');
 
@@ -508,7 +577,9 @@ function xml_to_graph_template($hash, &$xml_array, &$hash_cache, $hash_version,
 			}
 
 			/* invalid/wrong hash */
-			if ($parsed_hash == false) { return false; }
+			if ($parsed_hash == false) {
+				return false;
+			}
 
 			unset($save);
 			$_graph_template_item_id = db_fetch_cell_prepared('SELECT id
@@ -551,6 +622,10 @@ function xml_to_graph_template($hash, &$xml_array, &$hash_cache, $hash_version,
 							$color_id = db_fetch_insert_id();
 						}
 
+						if (empty($color_id) && $preview_only) {
+							$color_id = $item_array[$field_name];
+						}
+
 						$save[$field_name] = $color_id;
 					} else {
 						$save[$field_name] = xml_character_decode($item_array[$field_name]);
@@ -584,7 +659,9 @@ function xml_to_graph_template($hash, &$xml_array, &$hash_cache, $hash_version,
 			$parsed_hash = parse_xml_hash($item_hash);
 
 			/* invalid/wrong hash */
-			if ($parsed_hash == false) { return false; }
+			if ($parsed_hash == false) {
+				return false;
+			}
 
 			unset($save);
 			$_graph_template_input_id = db_fetch_cell_prepared('SELECT id
@@ -630,7 +707,9 @@ function xml_to_graph_template($hash, &$xml_array, &$hash_cache, $hash_version,
 						$parsed_hash = parse_xml_hash($hash_items[$i]);
 
 						/* invalid/wrong hash */
-						if ($parsed_hash == false) { return false; }
+						if ($parsed_hash == false) {
+							return false;
+						}
 
 						if (isset($hash_cache['graph_template_item'][$parsed_hash['hash']])) {
 							db_execute_prepared('REPLACE INTO graph_template_input_defs
@@ -646,19 +725,23 @@ function xml_to_graph_template($hash, &$xml_array, &$hash_cache, $hash_version,
 
 	/* status information that will be presented to the user */
 	$import_debug_info['type']   = (empty($_graph_template_id) ? 'new' : ($status > 0 ? 'updated':'unchanged'));
+	$import_debug_info['hash']   = $hash;
 	$import_debug_info['title']  = $xml_array['name'];
 	$import_debug_info['result'] = ($preview_only ? 'preview':(empty($graph_template_id) ? 'fail' : 'success'));
 
 	if (isset($new_items) && cacti_sizeof($new_items)) {
 		$new_text = array();
+
 		foreach($new_items as $item) {
 			$new_text[] = 'New Graph Items, Type: ' . $graph_item_types[$item['graph_type_id']] . ', Text Format: ' . $item['text_format'] . ', Value: ' . $item['value'];
 		}
+
 		$import_debug_info['new_items'] = $new_text;
 	}
 
 	if (isset($orphaned_items) && cacti_sizeof($orphaned_items)) {
 		$orphan_text = array();
+
 		foreach($orphaned_items as $item) {
 			if ($remove_orphans) {
 				$orphan_text[] = 'Removed Orphaned Graph Items, Type: ' . $graph_item_types[$item['graph_type_id']] . ', Text Format: ' . $item['text_format'] . ', Value: ' . $item['value'];
@@ -674,6 +757,7 @@ function xml_to_graph_template($hash, &$xml_array, &$hash_cache, $hash_version,
 				$orphan_text[] = 'Found Orphaned Graph Items, Type: ' . $graph_item_types[$item['graph_type_id']] . ', Text Format: ' . $item['text_format'] . ', Value: ' . $item['value'];
 			}
 		}
+
 		$import_debug_info['orphans'] = $orphan_text;
 
 		if ($remove_orphans) {
@@ -685,7 +769,8 @@ function xml_to_graph_template($hash, &$xml_array, &$hash_cache, $hash_version,
 }
 
 function xml_to_data_template($hash, &$xml_array, &$hash_cache, $import_as_new, $profile_id) {
-	global $struct_data_source, $struct_data_source_item, $import_template_id, $preview_only, $import_debug_info, $legacy_template;
+	global $struct_data_source, $struct_data_source_item, $import_template_id, $preview_only;
+	global $ignorable_hashes, $import_debug_info, $legacy_template;
 
 	/* track changes */
 	$status = 0;
@@ -797,7 +882,9 @@ function xml_to_data_template($hash, &$xml_array, &$hash_cache, $import_as_new,
 			$parsed_hash = parse_xml_hash($item_hash);
 
 			/* invalid/wrong hash */
-			if ($parsed_hash == false) { return false; }
+			if ($parsed_hash == false) {
+				return false;
+			}
 
 			unset($save);
 			$_data_template_rrd_id = db_fetch_cell_prepared('SELECT id
@@ -897,6 +984,13 @@ function xml_to_data_template($hash, &$xml_array, &$hash_cache, $import_as_new,
 	if (!$preview_only) {
 		if (is_array($xml_array['data'])) {
 			foreach ($xml_array['data'] as $item_hash => $item_array) {
+				$data_hash = parse_xml_hash($item_array['data_input_field_id']);
+
+				// Skip bad SNMP port hashes
+				if (array_search($data_hash['hash'], $ignorable_hashes) !== false) {
+					continue;
+				}
+
 				unset($save);
 				$save['data_template_data_id'] = $data_template_data_id;
 				$save['data_input_field_id']   = resolve_hash_to_id($item_array['data_input_field_id'], $hash_cache);
@@ -927,13 +1021,14 @@ function xml_to_data_template($hash, &$xml_array, &$hash_cache, $import_as_new,
 
 	/* status information that will be presented to the user */
 	$import_debug_info['type']   = (empty($_data_template_id) ? 'new' : ($status > 0 ? 'updated':'unchanged'));
+	$import_debug_info['hash']   = $hash;
 	$import_debug_info['title']  = $xml_array['name'];
 	$import_debug_info['result'] = ($preview_only ? 'preview':(empty($data_template_id) ? 'fail' : 'success'));
 
 	return $hash_cache;
 }
 
-function xml_to_data_query($hash, &$xml_array, &$hash_cache) {
+function xml_to_data_query($hash, &$xml_array, &$hash_cache, $replace_svalues = false) {
 	global $config, $fields_data_query_edit, $fields_data_query_item_edit, $preview_only, $import_debug_info;
 
 	static $counter = 0;
@@ -1002,7 +1097,9 @@ function xml_to_data_query($hash, &$xml_array, &$hash_cache) {
 			$parsed_hash = parse_xml_hash($item_hash);
 
 			/* invalid/wrong hash */
-			if ($parsed_hash == false) { return false; }
+			if ($parsed_hash == false) {
+				return false;
+			}
 
 			unset($save);
 			$_data_query_graph_id = db_fetch_cell_prepared('SELECT id
@@ -1068,12 +1165,21 @@ function xml_to_data_query($hash, &$xml_array, &$hash_cache) {
 
 			/* import into: snmp_query_graph_sv */
 			if (is_array($item_array['sv_graph'])) {
+				/* if the user choose to replace data query suggested values */
+				if ($data_query_graph_id > 0 && $replace_svalues) {
+					db_execute_prepared('DELETE FROM snmp_query_graph_sv
+						WHERE snmp_query_graph_id = ?',
+						array($data_query_graph_id));
+				}
+
 				foreach ($item_array['sv_graph'] as $sub_item_hash => $sub_item_array) {
 					/* parse information from the hash */
 					$parsed_hash = parse_xml_hash($sub_item_hash);
 
 					/* invalid/wrong hash */
-					if ($parsed_hash == false) { return false; }
+					if ($parsed_hash == false) {
+						return false;
+					}
 
 					unset($save);
 					$_data_query_graph_sv_id = db_fetch_cell_prepared('SELECT id
@@ -1113,12 +1219,21 @@ function xml_to_data_query($hash, &$xml_array, &$hash_cache) {
 
 			/* import into: snmp_query_graph_rrd_sv */
 			if (is_array($item_array['sv_data_source'])) {
+				/* if the user choose to replace data query suggested values */
+				if ($data_query_graph_id > 0 && $replace_svalues) {
+					db_execute_prepared('DELETE FROM snmp_query_graph_rrd_sv
+						WHERE snmp_query_graph_id = ?',
+						array($data_query_graph_id));
+				}
+
 				foreach ($item_array['sv_data_source'] as $sub_item_hash => $sub_item_array) {
 					/* parse information from the hash */
 					$parsed_hash = parse_xml_hash($sub_item_hash);
 
 					/* invalid/wrong hash */
-					if ($parsed_hash == false) { return false; }
+					if ($parsed_hash == false) {
+						return false;
+					}
 
 					unset($save);
 					$_data_query_graph_rrd_sv_id = db_fetch_cell_prepared('SELECT id
@@ -1165,6 +1280,7 @@ function xml_to_data_query($hash, &$xml_array, &$hash_cache) {
 
 	/* status information that will be presented to the user */
 	$import_debug_info['type']   = (empty($_data_query_id) ? 'new' : ($status > 0 ? 'updated':'unchanged'));
+	$import_debug_info['hash']   = $hash;
 	$import_debug_info['title']  = $xml_array['name'];
 	$import_debug_info['result'] = ($preview_only ? 'preview':(empty($data_query_id) ? 'fail' : 'success'));
 
@@ -1215,6 +1331,7 @@ function xml_to_gprint_preset($hash, &$xml_array, &$hash_cache) {
 
 	/* status information that will be presented to the user */
 	$import_debug_info['type']   = (empty($_gprint_preset_id) ? 'new' : ($status > 0 ? 'updated':'unchanged'));
+	$import_debug_info['hash']   = $hash;
 	$import_debug_info['title']  = $xml_array['name'];
 	$import_debug_info['result'] = ($preview_only ? 'preview':(empty($gprint_preset_id) ? 'fail' : 'success'));
 
@@ -1286,6 +1403,7 @@ function xml_to_data_source_profile($hash, &$xml_array, &$hash_cache, $import_as
 
 		/* status information that will be presented to the user */
 		$import_debug_info['type']   = 'new';
+		$import_debug_info['hash']   = $save['hash'];
 		$import_debug_info['title']  = $xml_array['name'] . ' (imported)';
 		$import_debug_info['result'] = ($preview_only ? 'preview':(empty($dsp_id) ? 'fail' : 'success'));
 
@@ -1344,7 +1462,9 @@ function xml_to_host_template($hash, &$xml_array, &$hash_cache) {
 				$parsed_hash = parse_xml_hash($hash_items[$i]);
 
 				/* invalid/wrong hash */
-				if ($parsed_hash == false) { return false; }
+				if ($parsed_hash == false) {
+					return false;
+				}
 
 				if (isset($hash_cache['graph_template'][$parsed_hash['hash']])) {
 					db_execute_prepared('REPLACE INTO host_template_graph
@@ -1364,7 +1484,9 @@ function xml_to_host_template($hash, &$xml_array, &$hash_cache) {
 				$parsed_hash = parse_xml_hash($hash_items[$i]);
 
 				/* invalid/wrong hash */
-				if ($parsed_hash == false) { return false; }
+				if ($parsed_hash == false) {
+					return false;
+				}
 
 				if (isset($hash_cache['data_query'][$parsed_hash['hash']])) {
 					db_execute_prepared('REPLACE INTO host_template_snmp_query
@@ -1380,6 +1502,7 @@ function xml_to_host_template($hash, &$xml_array, &$hash_cache) {
 
 	/* status information that will be presented to the user */
 	$import_debug_info['type']   = (empty($_host_template_id) ? 'new' : ($status > 0 ? 'updated':'unchanged'));
+	$import_debug_info['hash']   = $hash;
 	$import_debug_info['title']  = $xml_array['name'];
 	$import_debug_info['result'] = ($preview_only ? 'preview':(empty($host_template_id) ? 'fail' : 'success'));
 
@@ -1443,7 +1566,9 @@ function xml_to_cdef($hash, &$xml_array, &$hash_cache) {
 			$parsed_hash = parse_xml_hash($item_hash);
 
 			/* invalid/wrong hash */
-			if ($parsed_hash == false) { return false; }
+			if ($parsed_hash == false) {
+				return false;
+			}
 
 			unset($save);
 			$_cdef_item_id = db_fetch_cell_prepared('SELECT id
@@ -1478,7 +1603,9 @@ function xml_to_cdef($hash, &$xml_array, &$hash_cache) {
 						$parsed_item_hash = parse_xml_hash($item_array['value']);
 
 						/* invalid/wrong hash */
-						if ($parsed_item_hash == false) { return false; }
+						if ($parsed_item_hash == false) {
+							return false;
+						}
 
 						$_cdef_id = db_fetch_cell_prepared('SELECT id
 							FROM cdef
@@ -1507,6 +1634,7 @@ function xml_to_cdef($hash, &$xml_array, &$hash_cache) {
 
 	/* status information that will be presented to the user */
 	$import_debug_info['type']   = (empty($_cdef_id) ? 'new' : ($status > 0 ? 'updated':'unchanged'));
+	$import_debug_info['hash']   = $hash;
 	$import_debug_info['title']  = $xml_array['name'];
 	$import_debug_info['result'] = ($preview_only ? 'preview':(empty($cdef_id) ? 'fail' : 'success'));
 
@@ -1567,7 +1695,9 @@ function xml_to_vdef($hash, &$xml_array, &$hash_cache) {
 			$parsed_hash = parse_xml_hash($item_hash);
 
 			/* invalid/wrong hash */
-			if ($parsed_hash == false) { return false; }
+			if ($parsed_hash == false) {
+				return false;
+			}
 
 			unset($save);
 			$_vdef_item_id = db_fetch_cell_prepared('SELECT id
@@ -1612,17 +1742,17 @@ function xml_to_vdef($hash, &$xml_array, &$hash_cache) {
 
 	/* status information that will be presented to the user */
 	$import_debug_info['type']   = (empty($_vdef_id) ? 'new' : ($status > 0 ? 'updated':'unchanged'));
+	$import_debug_info['hash']   = $hash;
 	$import_debug_info['title']  = $xml_array['name'];
 	$import_debug_info['result'] = ($preview_only ? 'preview':(empty($vdef_id) ? 'fail' : 'success'));
 
 	return $hash_cache;
 }
 
-function xml_to_data_input_method($hash, &$xml_array, &$hash_cache) {
-	global $fields_data_input_edit, $fields_data_input_field_edit, $fields_data_input_field_edit_1, $preview_only, $import_debug_info;
+function xml_detect_ignorable_hash_cache($hash, &$xml_array) {
+	global $ignorable_hashes;
 
-	/* track changes */
-	$status = 0;
+	$found = false;
 
 	$system_hashes = array(
 		'3eb92bb845b9660a7445cf9740726522', // Get SNMP Data
@@ -1631,11 +1761,35 @@ function xml_to_data_input_method($hash, &$xml_array, &$hash_cache) {
 		'332111d8b54ac8ce939af87a7eac0c06', // Get Script Server Data (Indexed)
 	);
 
+	$valid_snmp_port_hashes = array(
+		'c1f36ee60c3dc98945556d57f26e475b',
+		'fc64b99742ec417cc424dbf8c7692d36'
+	);
+
 	// Leave system data input methods alone
 	if (array_search($hash, $system_hashes) !== false) {
-		return $hash_cache;
+		foreach($xml_array['fields'] as $input_hash => $field) {
+			if ($field['type_code'] == 'snmp_port') {
+				$parsed_hash = parse_xml_hash($input_hash);
+				$hash = $parsed_hash['hash'];
+				if (array_search($hash, $valid_snmp_port_hashes) === false) {
+					$ignorable_hashes[$input_hash] = $hash;
+					$found = true;
+				}
+			}
+		}
 	}
 
+	return $found;
+}
+
+function xml_to_data_input_method($hash, &$xml_array, &$hash_cache) {
+	global $fields_data_input_edit, $fields_data_input_field_edit, $fields_data_input_field_edit_1;
+	global $preview_only, $import_debug_info, $ignorable_hashes;
+
+	/* track changes */
+	$status = 0;
+
 	/* aggregate field arrays */
 	$fields_data_input_field_edit += $fields_data_input_field_edit_1;
 
@@ -1703,7 +1857,9 @@ function xml_to_data_input_method($hash, &$xml_array, &$hash_cache) {
 			$parsed_hash = parse_xml_hash($item_hash);
 
 			/* invalid/wrong hash */
-			if ($parsed_hash == false) { return false; }
+			if ($parsed_hash == false) {
+				return false;
+			}
 
 			/* bad snmp port hashes */
 			if ($parsed_hash['hash'] == '5240353b8f7f259acaf30e6229bc14e7') {
@@ -1741,6 +1897,9 @@ function xml_to_data_input_method($hash, &$xml_array, &$hash_cache) {
 
 				/* make sure this field exists in the xml array first */
 				if (isset($item_array[$field_name])) {
+					// Correct a nasty spelling error
+					$item_array[$field_name] = str_replace('Authenticaion', 'Authentication', $item_array[$field_name]);
+
 					$save[$field_name] = xml_character_decode($item_array[$field_name]);
 				}
 			}
@@ -1769,6 +1928,7 @@ function xml_to_data_input_method($hash, &$xml_array, &$hash_cache) {
 
 	/* status information that will be presented to the user */
 	$import_debug_info['type']   = (empty($_data_input_id) ? 'new' : ($status > 0 ? 'updated':'unchanged'));
+	$import_debug_info['hash']   = $hash;
 	$import_debug_info['title']  = $xml_array['name'];
 	$import_debug_info['result'] = ($preview_only ? 'preview':(empty($data_input_id) ? 'fail' : 'success'));
 
@@ -1820,8 +1980,28 @@ function compare_data($save, $previous_data, $table) {
 					continue;
 				}
 
+				if ($column == 'color_id') {
+					$oldvalue = db_fetch_cell_prepared('SELECT hex FROM colors WHERE id = ?', array($previous_data[$column]));
+					$oldvalue = html_escape($oldvalue);
+					$oldvalue = '<span style="background-color:#' . $oldvalue . '">' . $oldvalue . '</span>';
+
+					$newvalue = db_fetch_cell_prepared('SELECT hex FROM colors WHERE id = ?', array($value));
+
+					if (empty($newvalue) && $preview_only) {
+						$newvalue = html_escape($value);
+					} else {
+						$newvalue = html_escape($newvalue);
+					}
+
+					$newvalue = '<span style="background-color:#' . $newvalue . '">' . $newvalue . '</span>';
+				} else {
+					$oldvalue = html_escape($previous_data[$column]);
+					$newvalue = html_escape($value);
+				}
+
 				$different++;
-				$import_debug_info['differences'][] = 'Table: ' . $table . ', Column: ' . $column . ', New Value: ' . html_escape($value) . ', Old Value: ' . html_escape($previous_data[$column]);
+
+				$import_debug_info['differences'][] = 'Table: ' . $table . ', Column: ' . $column . ', New Value: ' . $newvalue . ', Old Value: ' . $oldvalue;
 			}
 		}
 
@@ -1923,10 +2103,13 @@ function resolve_hash_to_id($hash, &$hash_cache_array) {
 	$parsed_hash = parse_xml_hash($hash);
 
 	/* invalid/wrong hash */
-	if ($parsed_hash == false) { return false; }
+	if ($parsed_hash == false) {
+		return false;
+	}
 
 	if (isset($hash_cache_array[$parsed_hash['type']][$parsed_hash['hash']])) {
 		$import_debug_info['dep'][$hash] = 'met';
+
 		return $hash_cache_array[$parsed_hash['type']][$parsed_hash['hash']];
 	} else {
 		/* bad snmp port hashes */
@@ -2077,7 +2260,11 @@ function xml_character_decode($text) {
 }
 
 function import_display_results($import_debug_info, $filestatus, $web = false, $preview = false) {
-	global $hash_type_names;
+	global $hash_type_names, $ignorable_hashes;
+
+	if (!cacti_sizeof($ignorable_hashes)) {
+		$ignorable_hashes = array();
+	}
 
 	// Capture to a buffer
 	ob_start();
@@ -2087,52 +2274,52 @@ function import_display_results($import_debug_info, $filestatus, $web = false, $
 
 		if (cacti_sizeof($filestatus)) {
 			if ($preview) {
-				print "<tr class='odd'><td><p class='textArea'>" . __('Cacti would make the following changes if the Package was imported:') . "</p>\n";
+				print "<tr class='odd'><td><p class='textArea'>" . __('Cacti would make the following changes if the Package was imported:') . '</p>';
 			} else {
-				print "<tr class='odd'><td><p class='textArea'>" . __('Cacti has imported the following items for the Package:') . "</p>\n";
+				print "<tr class='odd'><td><p class='textArea'>" . __('Cacti has imported the following items for the Package:') . '</p>';
 			}
 
-			print "<p><strong>" . __('Package Files') . "</strong></p>\n";
+			print "<p><strong>" . __('Package Files') . "</strong></p>";
 
-			print "<ul>";
+			print '<ul>';
 			foreach($filestatus as $filename => $status) {
-				print "<li>" . ($preview ? __("[preview] "):"") . html_escape($filename) . " [" . $status . "]</li>\n";
+				print '<li>' . ($preview ? __("[preview] "):"") . html_escape($filename) . ' [' . $status . ']</li>';
 			}
-			print "</ul>";
+			print '</ul>';
 		} else {
 			if ($preview) {
-				print "<tr class='odd'><td><p class='textArea'>" . __('Cacti would make the following changes if the Template was imported:') . "</p>\n";
+				print "<tr class='odd'><td><p class='textArea'>" . __('Cacti would make the following changes if the Template was imported:') . '</p>';
 			} else {
-				print "<tr class='odd'><td><p class='textArea'>" . __('Cacti has imported the following items for the Template:') . "</p>\n";
+				print "<tr class='odd'><td><p class='textArea'>" . __('Cacti has imported the following items for the Template:') . '</p>';
 			}
 		}
 
 		foreach ($import_debug_info as $type => $type_array) {
-			print "<p><strong>" . $hash_type_names[$type] . "</strong></p>\n";
+			print "<p><strong>" . $hash_type_names[$type] . "</strong></p>";
 
 			foreach ($type_array as $index => $vals) {
 				if ($vals['result'] == 'success') {
-					$result_text = "<span class='success'>" . __('[success]') . "</span>";
+					$result_text = "<span class='success'>" . __('[success]') . '</span>';
 				} elseif ($vals['result'] == 'fail') {
-					$result_text = "<span class='failed'>" . __('[fail]') . "</span>";
+					$result_text = "<span class='failed'>" . __('[fail]') . '</span>';
 				} else {
-					$result_text = "<span class='success'>" . __('[preview]') . "</span>";
+					$result_text = "<span class='success'>" . __('[preview]') . '</span>';
 				}
 
 				if ($vals['type'] == 'updated') {
-					$type_text = "<span class='updateObject'>" . __('[updated]') . "</span>\n";
+					$type_text = "<span class='updateObject'>" . __('[updated]') . '</span>';
 				} elseif ($vals['type'] == 'new') {
-					$type_text = "<span class='newObject'>" . __('[new]') . "</span>\n";
+					$type_text = "<span class='newObject'>" . __('[new]') . '</span>';
 				} else {
-					$type_text = "<span class='deviceUp'>" . __('[unchanged]') . "</span>\n";
+					$type_text = "<span class='deviceUp'>" . __('[unchanged]') . '</span>';
 				}
 
-				print "<span class='monoSpace'>$result_text " . html_escape($vals['title']) . " $type_text</span><br>\n";
+				print "<span class='monoSpace'>$result_text " . html_escape($vals['title']) . " $type_text</span><br>";
 
 				if (isset($vals['orphans'])) {
 					print '<ul class="monoSpace">';
 					foreach($vals['orphans'] as $orphan) {
-						print "<li>" . html_escape($orphan) . "</li>\n";
+						print '<li>' . html_escape($orphan) . '</li>';
 					}
 					print '</ul>';
 				}
@@ -2140,7 +2327,7 @@ function import_display_results($import_debug_info, $filestatus, $web = false, $
 				if (isset($vals['new_items'])) {
 					print '<ul class="monoSpace">';
 					foreach($vals['new_items'] as $item) {
-						print "<li>" . html_escape($item) . "</li>\n";
+						print '<li>' . html_escape($item) . '</li>';
 					}
 					print '</ul>';
 				}
@@ -2148,7 +2335,7 @@ function import_display_results($import_debug_info, $filestatus, $web = false, $
 				if (isset($vals['differences'])) {
 					print '<ul class="monoSpace">';
 					foreach($vals['differences'] as $diff) {
-						print "<li>" . html_escape($diff) . "</li>\n";
+						print '<li>' . $diff . '</li>';
 					}
 					print '</ul>';
 				}
@@ -2160,13 +2347,13 @@ function import_display_results($import_debug_info, $filestatus, $web = false, $
 					if ((isset($vals['dep'])) && (cacti_sizeof($vals['dep']) > 0)) {
 						foreach ($vals['dep'] as $dep_hash => $dep_status) {
 							if ($dep_status == 'met') {
-								$dep_status_text = "<span class='foundDependency'>" . __('Found Dependency:') . "</span>";
-							} else {
-								$dep_status_text = "<span class='unmetDependency'>" . __('Unmet Dependency:') . "</span>";
+								$dep_status_text = "<span class='foundDependency'>" . __('Found Dependency:') . '</span>';
+							} elseif (array_search($dep_hash, $ignorable_hashes) === false) {
+								$dep_status_text = "<span class='unmetDependency'>" . __('Unmet Dependency:') . '</span>';
 								$dep_errors = true;
 							}
 
-							$dep_text .= "<span class='monoSpace'>&nbsp;&nbsp;&nbsp;+ $dep_status_text " . hash_to_friendly_name($dep_hash, true) . "</span><br>\n";
+							$dep_text .= "<span class='monoSpace'>&nbsp;&nbsp;&nbsp;+ $dep_status_text " . hash_to_friendly_name($dep_hash, true) . "</span><br>";
 						}
 					}
 
